{#
    basic/searchresults.html
    ~~~~~~~~~~~~~~~~~~~~~~~~

    Template for the body of the search results page.

    :copyright: Copyright 2007-2011 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
<h1 id="search-documentation">Search</h1>
<p>
  From here you can search these documents. Enter your search
  words into the box below and click "search".
</p>

<form class="form-search" action="" method="get">
  <input type="text" name="q" class="input-medium search-query">
  <button type="submit" class="btn">{{ _('search') }}</button>
  <span id="search-progress" style="padding-left: 10px"></span>
</form>

{%- if search_performed %}
  <h2>Search Results</h2>
  {%- if not search_results %}
  <p>Your search did not match any results.</p>
  {%- endif %}
{%- endif %}
<div id="search-results">
  {%- if search_results %}
  <ul>
    {% for href, caption, context in search_results %}
    <li class="card">
      <div class="card-block">
        <h3 class="card-title"><a href="{{ docroot }}{{ href }}/?highlight={{ q }}">{{ caption }}</a></h3>
        <div class="context">{{ context|e }}</div>
      </div>
    </li>
    {% endfor %}
  </ul>
  {%- endif %}
</div>
